@@ -60,24 +60,25 @@ def second_splitters(requests, group_by=None, **kwargs):
         s = high_frequency_splitter(s)
 
     s = constant_splitter(s)
+
     if config("free-open-data"):
         s = free_splitter(
             s,
             "free-open-data",
-            # canonical_grid([0.4, 0.4]),
         )
+
     if config("free-wmo-essential"):
         s = free_splitter(
             s,
             "free-wmo-essential",
-            # canonical_grid([0.5, 0.5]),
         )
 
     if config("free-data"):
-        s = free_splitter(
-            s,
-            config("free-data"),
-        )
+        for free in config("free-data"):
+            s = free_splitter(
+                s,
+                free,
+            )
 
     s = freebies_splitter(s)
     return s
